@@ -23,6 +23,8 @@
 #ifndef __GUPNP_DIDL_LITE_CONTRIBUTOR_PRIVATE_H__
 #define __GUPNP_DIDL_LITE_CONTRIBUTOR_PRIVATE_H__
 
+#include "xml-util.h"
+
 #include <glib-object.h>
 #include <libxml/tree.h>
 
@@ -32,7 +34,7 @@ G_BEGIN_DECLS
 
 GUPnPDIDLLiteContributor *
 gupnp_didl_lite_contributor_new_from_xml (xmlNode     *xml_node,
-                                          GUPnPXMLDoc *xml_doc);
+                                          GUPnPAVXMLDoc *xml_doc);
 
 G_END_DECLS
 
