@@ -30,7 +30,6 @@
  */
 
 #include <string.h>
-#include <libgupnp/gupnp.h>
 
 #include "gupnp-didl-lite-object.h"
 #include "gupnp-didl-lite-object-private.h"
@@ -48,8 +47,8 @@ G_DEFINE_ABSTRACT_TYPE (GUPnPDIDLLiteObject,
                         G_TYPE_OBJECT);
 
 struct _GUPnPDIDLLiteObjectPrivate {
-        xmlNode     *xml_node;
-        GUPnPXMLDoc *xml_doc;
+        xmlNode       *xml_node;
+        GUPnPAVXMLDoc *xml_doc;
 
         xmlNs *upnp_ns;
         xmlNs *dc_ns;
@@ -124,7 +123,7 @@ gupnp_didl_lite_object_set_property (GObject      *object,
                 didl_object->priv->xml_node = g_value_get_pointer (value);
                 break;
         case PROP_XML_DOC:
-                didl_object->priv->xml_doc = g_value_dup_object (value);
+                didl_object->priv->xml_doc = g_value_dup_boxed (value);
                 break;
         case PROP_UPNP_NAMESPACE:
                 didl_object->priv->upnp_ns = g_value_get_pointer (value);
@@ -367,10 +366,7 @@ gupnp_didl_lite_object_dispose (GObject *object)
 
         priv = GUPNP_DIDL_LITE_OBJECT (object)->priv;
 
-        if (priv->xml_doc) {
-                g_object_unref (priv->xml_doc);
-                priv->xml_doc = NULL;
-        }
+        g_clear_pointer (&priv->xml_doc, xml_doc_unref);
 
         object_class = G_OBJECT_CLASS (gupnp_didl_lite_object_parent_class);
         object_class->dispose (object);
@@ -419,11 +415,11 @@ gupnp_didl_lite_object_class_init (GUPnPDIDLLiteObjectClass *klass)
         g_object_class_install_property
                 (object_class,
                  PROP_XML_DOC,
-                 g_param_spec_object ("xml-doc",
+                 g_param_spec_boxed ("xml-doc",
                                       "XMLDoc",
                                       "The reference to XML document"
                                       " containing this object.",
-                                      GUPNP_TYPE_XML_DOC,
+                                      xml_doc_get_type (),
                                       G_PARAM_WRITABLE |
                                       G_PARAM_CONSTRUCT_ONLY |
                                       G_PARAM_STATIC_NAME |
@@ -954,12 +950,12 @@ unset_contributors_by_name (GUPnPDIDLLiteObject *object, const char *name)
  * Return value: A new #GUPnPDIDLLiteObject object. Unref after usage.
  **/
 GUPnPDIDLLiteObject *
-gupnp_didl_lite_object_new_from_xml (xmlNode     *xml_node,
-                                     GUPnPXMLDoc *xml_doc,
-                                     xmlNs       *upnp_ns,
-                                     xmlNs       *dc_ns,
-                                     xmlNs       *dlna_ns,
-                                     xmlNs       *pv_ns)
+gupnp_didl_lite_object_new_from_xml (xmlNode       *xml_node,
+                                     GUPnPAVXMLDoc *xml_doc,
+                                     xmlNs         *upnp_ns,
+                                     xmlNs         *dc_ns,
+                                     xmlNs         *dlna_ns,
+                                     xmlNs         *pv_ns)
 {
         g_return_val_if_fail (xml_node != NULL, NULL);
         g_return_val_if_fail (xml_node->name != NULL, NULL);
@@ -995,7 +991,7 @@ gupnp_didl_lite_object_new_from_xml (xmlNode     *xml_node,
  * Returns: (transfer none): The pointer to the XML document containing this
  * object.
  **/
-GUPnPXMLDoc *
+GUPnPAVXMLDoc *
 gupnp_didl_lite_object_get_gupnp_xml_doc (GUPnPDIDLLiteObject *object)
 {
         g_return_val_if_fail (GUPNP_IS_DIDL_LITE_OBJECT (object), NULL);
